@@ -3,16 +3,13 @@
 # email:yuyc@ishangqi.com
 # date:2021/11/26 3:56 下午
 # Copyright (C) 2021 The lesscode Team
-import json
-
 import neo4j.data
+import neo4j.graph
 from tornado.options import options
 
 import logging
 import traceback
 
-from neo4j import WorkspaceConfig
-
 from lesscode.db.page import Page
 from lesscode.utils.encryption_algorithm import AES
 
@@ -76,8 +73,7 @@ class Neo4jHelper:
         async for record in result.records():
             item = {}
             for args in str(record).split('>')[0].split()[1:]:
-                exec
-                "item.update(dict({0}))".format(args)
+                exec("item.update(dict({0}))".format(args))
             data.append(item)
         await self.pool.close()
         return data
@@ -91,7 +87,7 @@ class Neo4jHelper:
         :param keys: list, default : none(call dictreader())
             Cypher query columns to return.
         :return: list.
-            Each returned record constructs an dict in "key : value" pairs and stored in a list, [{...}, {...}, ...].
+            Each returned record constructs a dict in "key : value" pairs and stored in a list, [{...}, {...}, ...].
         """
         if not keys:
             return await self.dictreader(cypher)
@@ -146,12 +142,15 @@ class Neo4jHelper:
                             relation_item_list = parse_relation_item_more_relation(item[0], id_key, name_key)
                             data = data + relation_item_list
                 stock_strike = False
-            except Exception:
+            except Exception as e:
+                logging.error(e)
                 logging.error(traceback.format_exc())
             num = num + 1
         return data
 
-    async def create_node(self, node_name: str, label_name: str, node_property: dict = {}):
+    async def create_node(self, node_name: str, label_name: str, node_property=None):
+        if node_property is None:
+            node_property = {}
         sql = f"CREATE ({node_name}:{label_name} {dict_str(node_property)})"
         result = await self.execute_write(sql)
         return result
@@ -162,8 +161,12 @@ class Neo4jHelper:
         result = await self.execute_write(sql)
         return result
 
-    async def delete_node(self, node_name: str, label_name: str, match_property_dict: dict = {},
-                          node_property_dict: dict = {}):
+    async def delete_node(self, node_name: str, label_name: str, match_property_dict=None,
+                          node_property_dict=None):
+        if match_property_dict is None:
+            match_property_dict = {}
+        if node_property_dict is None:
+            node_property_dict = {}
         sql = f"MATCH ({node_name}:{label_name}"
         if match_property_dict:
             sql += f"{dict_str(match_property_dict)})"
@@ -179,7 +182,11 @@ class Neo4jHelper:
         return result
 
     async def delete_property(self, node_name: str, label_name: str, delete_node_property_list: list,
-                              match_property_dict: dict = {}, node_property_dict: dict = {}):
+                              match_property_dict=None, node_property_dict=None):
+        if node_property_dict is None:
+            node_property_dict = {}
+        if match_property_dict is None:
+            match_property_dict = {}
         sql = f"MATCH ({node_name}:{label_name}"
         if match_property_dict:
             sql += f"{dict_str(match_property_dict)})"
@@ -196,7 +203,11 @@ class Neo4jHelper:
         return result
 
     async def update_node(self, node_name: str, label_name: str, new_node_property_dict: dict,
-                          match_property_dict: dict = {}, node_property_dict: dict = {}):
+                          match_property_dict=None, node_property_dict=None):
+        if node_property_dict is None:
+            node_property_dict = {}
+        if match_property_dict is None:
+            match_property_dict = {}
         new_node_property_str = ",".join(
             ['%s.%s=%r' % (node_name, property_name, property_value) for property_name, property_value in
              new_node_property_dict.items()])
@@ -215,9 +226,13 @@ class Neo4jHelper:
         return result
 
     async def delete_two_node_relationship(self, relationship_name: str, relationship: str, node1_name: str = None,
-                                           label1_name: str = None, node1_match_property_dict: dict = {},
+                                           label1_name: str = None, node1_match_property_dict=None,
                                            node2_name: str = None, label2_name: str = None,
-                                           node2_match_property_dict: dict = {}):
+                                           node2_match_property_dict=None):
+        if node1_match_property_dict is None:
+            node1_match_property_dict = {}
+        if node2_match_property_dict is None:
+            node2_match_property_dict = {}
         if node1_name:
             if label1_name and not node1_match_property_dict:
                 sql = f'MATCH ({node1_name}:{label1_name}'
@@ -259,8 +274,12 @@ class Neo4jHelper:
         return result
 
     async def delete_node_and_all_relationship(self, node_name: str = None, label_name: str = None,
-                                               match_property_dict: dict = {},
-                                               node_property_dict: dict = {}):
+                                               match_property_dict=None,
+                                               node_property_dict=None):
+        if node_property_dict is None:
+            node_property_dict = {}
+        if match_property_dict is None:
+            match_property_dict = {}
         if node_name:
             if label_name and not match_property_dict:
                 sql = f'MATCH ({node_name}:{label_name})'
@@ -290,9 +309,15 @@ class Neo4jHelper:
         return result
 
     async def query_node_relationship(self, relationship: str, node1_name: str = None, label1_name: str = None,
-                                      node1_match_property_dict: dict = {},
-                                      property_dict: dict = {}, node2_name: str = None, label2_name: str = None,
-                                      node2_match_property_dict: dict = {}, result_list: list = None):
+                                      node1_match_property_dict=None,
+                                      property_dict=None, node2_name: str = None, label2_name: str = None,
+                                      node2_match_property_dict=None, result_list: list = None):
+        if node2_match_property_dict is None:
+            node2_match_property_dict = {}
+        if property_dict is None:
+            property_dict = {}
+        if node1_match_property_dict is None:
+            node1_match_property_dict = {}
         if node1_name:
             if label1_name and not node1_match_property_dict:
                 sql = f'MATCH ({node1_name}:{label1_name})'
@@ -354,8 +379,12 @@ class Neo4jHelper:
             records.append(parse_record(record, flag=True))
         return records
 
-    async def query_all_node(self, node_name: str = None, label_name: str = None, match_property_dict: dict = {},
-                             node_property_dict: dict = {}, result_list: list = None):
+    async def query_all_node(self, node_name: str = None, label_name: str = None, match_property_dict=None,
+                             node_property_dict=None, result_list: list = None):
+        if match_property_dict is None:
+            match_property_dict = {}
+        if node_property_dict is None:
+            node_property_dict = {}
         if node_name:
             if label_name and not match_property_dict:
                 sql = f'MATCH ({node_name}:{label_name})'
@@ -391,8 +420,12 @@ class Neo4jHelper:
         await self.pool.close()
         return records
 
-    async def query_node_count(self, node_name: str = None, label_name: str = None, match_property_dict: dict = {},
-                               node_property_dict: dict = {}):
+    async def query_node_count(self, node_name: str = None, label_name: str = None, match_property_dict=None,
+                               node_property_dict=None):
+        if match_property_dict is None:
+            match_property_dict = {}
+        if node_property_dict is None:
+            node_property_dict = {}
         if node_name:
             if label_name and not match_property_dict:
                 sql = f'MATCH ({node_name}:{label_name})'
@@ -419,9 +452,13 @@ class Neo4jHelper:
         count = result[0].value()
         return count
 
-    async def query_node_page(self, node_name: str = None, label_name: str = None, match_property_dict: dict = {},
-                              node_property_dict: dict = {}, result_list: list = None,
+    async def query_node_page(self, node_name: str = None, label_name: str = None, match_property_dict=None,
+                              node_property_dict=None, result_list: list = None,
                               page_num: int = 1, page_size: int = 10):
+        if node_property_dict is None:
+            node_property_dict = {}
+        if match_property_dict is None:
+            match_property_dict = {}
         if node_name:
             if label_name and not match_property_dict:
                 sql = f'MATCH ({node_name}:{label_name})'
@@ -519,8 +556,7 @@ class Neo4jHelper:
             for record in tx.run(cypher).records():
                 item = {}
                 for args in str(record).split('>')[0].split()[1:]:
-                    exec
-                    "item.update(dict({0}))".format(args)
+                    exec("item.update(dict({0}))".format(args))
                 data.append(item)
         return data
 
@@ -533,7 +569,7 @@ class Neo4jHelper:
         :param keys: list, default : none(call dictreader())
             Cypher query columns to return.
         :return: list.
-            Each returned record constructs an dict in "key : value" pairs and stored in a list, [{...}, {...}, ...].
+            Each returned record constructs a dict in "key : value" pairs and stored in a list, [{...}, {...}, ...].
         """
         if not keys:
             return self.sync_dictreader(cypher)
@@ -590,7 +626,9 @@ class Neo4jHelper:
             num = num + 1
         return data
 
-    def sync_create_node(self, node_name: str, label_name: str, node_property: dict = {}):
+    def sync_create_node(self, node_name: str, label_name: str, node_property=None):
+        if node_property is None:
+            node_property = {}
         sql = f"CREATE ({node_name}:{label_name} {dict_str(node_property)})"
         result = self.sync_execute_write(sql)
         return result
@@ -601,8 +639,12 @@ class Neo4jHelper:
         result = self.sync_execute_write(sql)
         return result
 
-    def sync_delete_node(self, node_name: str, label_name: str, match_property_dict: dict = {},
-                         node_property_dict: dict = {}):
+    def sync_delete_node(self, node_name: str, label_name: str, match_property_dict=None,
+                         node_property_dict=None):
+        if node_property_dict is None:
+            node_property_dict = {}
+        if match_property_dict is None:
+            match_property_dict = {}
         sql = f"MATCH ({node_name}:{label_name}"
         if match_property_dict:
             sql += f"{dict_str(match_property_dict)})"
@@ -618,7 +660,11 @@ class Neo4jHelper:
         return result
 
     def sync_delete_property(self, node_name: str, label_name: str, delete_node_property_list: list,
-                             match_property_dict: dict = {}, node_property_dict: dict = {}):
+                             match_property_dict=None, node_property_dict=None):
+        if node_property_dict is None:
+            node_property_dict = {}
+        if match_property_dict is None:
+            match_property_dict = {}
         sql = f"MATCH ({node_name}:{label_name}"
         if match_property_dict:
             sql += f"{dict_str(match_property_dict)})"
@@ -635,7 +681,11 @@ class Neo4jHelper:
         return result
 
     def sync_update_node(self, node_name: str, label_name: str, new_node_property_dict: dict,
-                         match_property_dict: dict = {}, node_property_dict: dict = {}):
+                         match_property_dict=None, node_property_dict=None):
+        if node_property_dict is None:
+            node_property_dict = {}
+        if match_property_dict is None:
+            match_property_dict = {}
         new_node_property_str = ",".join(
             ['%s.%s=%r' % (node_name, property_name, property_value) for property_name, property_value in
              new_node_property_dict.items()])
@@ -654,9 +704,13 @@ class Neo4jHelper:
         return result
 
     def sync_delete_two_node_relationship(self, relationship_name: str, relationship: str, node1_name: str = None,
-                                          label1_name: str = None, node1_match_property_dict: dict = {},
+                                          label1_name: str = None, node1_match_property_dict=None,
                                           node2_name: str = None, label2_name: str = None,
-                                          node2_match_property_dict: dict = {}):
+                                          node2_match_property_dict=None):
+        if node1_match_property_dict is None:
+            node1_match_property_dict = {}
+        if node2_match_property_dict is None:
+            node2_match_property_dict = {}
         if node1_name:
             if label1_name and not node1_match_property_dict:
                 sql = f'MATCH ({node1_name}:{label1_name}'
@@ -698,8 +752,12 @@ class Neo4jHelper:
         return result
 
     def sync_delete_node_and_all_relationship(self, node_name: str = None, label_name: str = None,
-                                              match_property_dict: dict = {},
-                                              node_property_dict: dict = {}):
+                                              match_property_dict=None,
+                                              node_property_dict=None):
+        if node_property_dict is None:
+            node_property_dict = {}
+        if match_property_dict is None:
+            match_property_dict = {}
         if node_name:
             if label_name and not match_property_dict:
                 sql = f'MATCH ({node_name}:{label_name})'
@@ -729,10 +787,16 @@ class Neo4jHelper:
         return result
 
     def sync_query_node_relationship(self, relationship: str, node1_name: str = None, label1_name: str = None,
-                                     node1_match_property_dict: dict = {},
-                                     property_dict: dict = {}, node2_name: str = None, label2_name: str = None,
-                                     node2_match_property_dict: dict = {},
+                                     node1_match_property_dict=None,
+                                     property_dict=None, node2_name: str = None, label2_name: str = None,
+                                     node2_match_property_dict=None,
                                      result_list: list = None):
+        if node2_match_property_dict is None:
+            node2_match_property_dict = {}
+        if property_dict is None:
+            property_dict = {}
+        if node1_match_property_dict is None:
+            node1_match_property_dict = {}
         if node1_name:
             if label1_name and not node1_match_property_dict:
                 sql = f'MATCH ({node1_name}:{label1_name}'
@@ -795,8 +859,12 @@ class Neo4jHelper:
             records.append(parse_record(record, flag=True))
         return records
 
-    def sync_query_all_node(self, node_name: str = None, label_name: str = None, match_property_dict: dict = {},
-                            node_property_dict: dict = {}, result_list: list = None):
+    def sync_query_all_node(self, node_name: str = None, label_name: str = None, match_property_dict=None,
+                            node_property_dict=None, result_list: list = None):
+        if match_property_dict is None:
+            match_property_dict = {}
+        if node_property_dict is None:
+            node_property_dict = {}
         if node_name:
             if label_name and not match_property_dict:
                 sql = f'MATCH ({node_name}:{label_name})'
@@ -831,8 +899,12 @@ class Neo4jHelper:
             records.append(parse_record(record, flag=False))
         return records
 
-    def sync_query_node_count(self, node_name: str = None, label_name: str = None, match_property_dict: dict = {},
-                              node_property_dict: dict = {}):
+    def sync_query_node_count(self, node_name: str = None, label_name: str = None, match_property_dict=None,
+                              node_property_dict=None):
+        if match_property_dict is None:
+            match_property_dict = {}
+        if node_property_dict is None:
+            node_property_dict = {}
         if node_name:
             if label_name and not match_property_dict:
                 sql = f'MATCH ({node_name}:{label_name})'
@@ -858,9 +930,13 @@ class Neo4jHelper:
         count = self.pool.read_transaction(self.sync_query_work, sql)[0].value()
         return count
 
-    def sync_query_node_page(self, node_name: str = None, label_name: str = None, match_property_dict: dict = {},
-                             node_property_dict: dict = {}, result_list: list = None,
+    def sync_query_node_page(self, node_name: str = None, label_name: str = None, match_property_dict=None,
+                             node_property_dict=None, result_list: list = None,
                              page_num: int = 1, page_size: int = 10):
+        if match_property_dict is None:
+            match_property_dict = {}
+        if node_property_dict is None:
+            node_property_dict = {}
         if node_name:
             if label_name and not match_property_dict:
                 sql = f'MATCH ({node_name}:{label_name})'
