@@ -1,12 +1,11 @@
 import copy
 import datetime
 import functools
+import inspect
 import json
 import logging
 import traceback
 
-import tornado.web
-
 from lesscode.db.redis.redis_helper import RedisHelper
 from tornado.options import options
 
@@ -28,10 +27,11 @@ def Cache(ex=3600 * 8, cache_key=None):
 
 def deal_cache(func, ex, cache_key, *args, **params):
     # 获取缓存查询key
+    signature = inspect.signature(func)
     params = dict(sorted(params.items(), key=lambda x: x[0]))
     func_name = str(func).split(" ")[1]
     if not cache_key:
-        cache_key = format_insert_key(func_name, args, params)
+        cache_key = format_insert_key(signature, func_name, args, params)
     value = query_cache(cache_key)
     if value:
         data = value
@@ -60,21 +60,16 @@ def query_cache(cache_key, conn_name=options.cache_conn):
     return False
 
 
-def format_insert_key(func_name, args, params):
-    _args = []
-    for x in args:
-        if not issubclass(type(x), tornado.web.RequestHandler):
-            _args.append(x)
-    str_insert_key = str(_args)
+def format_insert_key(signature, func_name, args, params):
+    _args = args
+    param_keys = list(signature.parameters.keys())
+    if param_keys and args:
+        if param_keys[0] == "self":
+            _args = args[1:]
     for k in params:
-        if isinstance(params[k], dict):
-            a = json.dumps(params[k])
-        else:
-            a = str("" if params[k] is None else params[k])
-
-        str_insert_key = str_insert_key + a + "&"
-    str_insert_key = str_insert_key[:-1]
-    str_insert_key = options.route_prefix + func_name + "_" + str_insert_key
+        _args.append(json.dumps(params[k]))
+    str_insert_key = "&".join([str(x) for x in _args])
+    str_insert_key = options.route_prefix + func_name + "#" + str_insert_key
 
     return str_insert_key
 
